function [d,c]=spbssl(L,pscl)
% [d,c]=spbssl(L,pscl)
% Generates analog filter coefficients for Lth order normalized
% lowpass Bessel filter.  See Section 7.5.  Response at 1 rad/s
% equals response of unscaled H(s) at pscl rad/s. 
% Inputs:
%    L    = Order of normalized low-pass analog filter.
%    pscl = Controls frequency scaling such that response at 1
%           rad/s equals that of unscaled H(s) at pscl rad/s.
% Outputs:  
%    d      = D(s) coefficient row vector.
%    c      = C(s) coefficient row vector.

if (L<=0 | pscl<=0)
   error('SPBSSL: Called with L and/or pscl not valid.');
end
for k=0:L
   denom=(2^(L-k))*spbfct(k,k)*spbfct(L-k,L-k);
   c(k+1)=(pscl^k)*spbfct(2*L-k,2*L-k)/denom;
end
d(1)=c(1);
return
