function [y,nsgmts]=spcros(x1,x2,NDFT,iwindo,ovrlap)
% [y,nsgmts]=spcros(x1,x2,NDFT,iwindo,ovrlap)
% Similar to SPPOWR, but for the avg. cross-spectrum of x1 and x2.
% x1,x2=row vectors of same length; iwindo=window type;
% ovrlap=overlap.  y=cross spectrum; nsgmts=# segments avgd.
% Described in Chapter 4, Section 4.7.
% Inputs:
%    x1,x2  = Input row vectors, x1(1:N) and x2(1:N).
%    NDFT   = DFT length (even).  # spectral components = NDFT/2.
%    iwindo = Data window type:
%                1) Rectangular.                 4) Hanning.
%                2) Tapered rectangular.         5) Hamming.
%                3) Triangular.                  6) Blackman.
%    ovrlap = Fraction that each data segment of size NDFT
%                overlaps its predecessor.  Must be greater than
%                or equal 0 and less than 1.
% Outputs:  
%    y      = Output avg. cross spectrum. Complex in general.
%    nsgmts = No. of overlapping segments of x averaged together.

N=length(x1);
if(N~=length(x2)),
   error('SPCROS: Lengths of x1 and x2 are unequal.');
elseif (N<NDFT)
   error('SPCROS: DFT size exceeds data length.');
elseif (NDFT<8)|(2*fix(NDFT/2)~=NDFT)
   error('SPCROS: DFT size (NDFT) is too small or is odd.');
end
Ny=fix(NDFT/2)+1;
y(1:Ny)=(1+j)*zeros(1,Ny);
nshift=fix(min(NDFT,max(1,fix(NDFT*(1-ovrlap)+.5))));
nsgmts=fix(1+(N-NDFT)/nshift);
for isegmt=0:nsgmts-1
   index=nshift*isegmt;
   temp=x1(index+1:index+NDFT)+j*x2(index+1:index+NDFT);
   [temp,tsv]=spmask(temp,iwindo);
   TEMP=fft(temp,NDFT);
   y(1)=y(1)+real(TEMP(1))*imag(TEMP(1))/(tsv*nsgmts);
   for m=2:Ny
      p=TEMP(m)+TEMP(NDFT-m+2);
      q=TEMP(m)-TEMP(NDFT-m+2);
      u=0.5*(real(p)+j*imag(q));
      v=0.5*(imag(p)-j*real(q));
      y(m)=y(m)+conj(u)*v/(tsv*nsgmts);
   end
end
return
