function b=spfird(L,iband,fln,fhn,iwndo)
% b=spfird(L,iband,fln,fhn,iwndo)
% FIR linear-phase digital filter design using windowed Fourier
% series. Filter coeff=b(0:L); iband=band; fln,fhn=low,high
% cutoff frequencies in Hz-s; iwndo=window number (1-6).
%Inputs:
%    L      = order; H(z)=b(1)+b(2)*z^(-1)+...+b(L+1)*z^(-L).
%             Note: Filter delay = L/2 samples, so L should be
%                   even for an integer delay value.
%    iband  = 1  Lowpass       3  Bandpass
%             2  Highpass      4  Bandstop
%    fln    = Normalized lower cutoff frequency in Hz-sec.
%    fhn    = Normalized upper (BP,BS) cutoff freq. in Hz-s.
%    iwndo  = Window used in FIR design. See Sect. 8.4.
% Outputs:  
%    b      = Digital filter coefficient row vector, b(1:L+1).

if L<=0,
   error('SPFIRD: L must be > 0.');
end
if (iwndo<1)|(iwndo>6),
   error('SPFIRD: iwindo must be in range [1,6].');
end
if (iband<1)|(iband>4),
   error('SPFIRD: iband must be in range [1,4].');
end
if (fln<=0)|(fln>=0.5) | (iband>=3 & (fln>=fhn | fhn>=0.5)),
   error('SPFIRD: fln and/or fhn are illegal.');
end
b=zeros(1,L+1);
dly=L/2;
lim=fix(dly);
if dly==lim,
   lim=lim-1;
   mid=1;
else
   mid=0;
end
wc1=2*pi*fln;
wc2=2*pi*fhn;
for i=0:lim,
   s=i-dly;
% Auxilliary function.
f1=sin(wc1*s);
f2=wc1/pi;
if(iband==2),
   f1=sin(pi*s)-f1;
   f2=1-f2;
elseif(iband==3),
   f1=sin(wc2*s)-f1;
   f2=wc2/pi-f2;
elseif(iband==4),
   f1=f1+sin(pi*s)-sin(wc2*s);
   f2=f2+1-wc2/pi;
end
%
   b(i+1)=(f1/(pi*s))*spwndo(iwndo,L+1,i+1);
   b(L+1-i)=b(i+1);
end
if mid==1,
   b(L/2+1)=f2;
end
return
