function b=sphilb(L)
% b=sphilb(L)
% Generates the weights of an FIR Hilbert transformer of length
% L. When used as a causal filter, B(z) has approx. unit gain,
% group delay of (L-1)/2, and approx. 90 deg. phase shift.
% Input:
%    L = Length of weight vector b.  Should be odd and >2.
% Output:  
%    b = weight row vector of Hilbert transformer;
%        B(z)=b(1) + b(2)*z^(-1) + ... + b(L)*z^(-(L-1)).

N=fix(L/2);
b=zeros(1,2*N+1);
b(N+2:2*N+1)=2*(sin(pi*(1:N)/2) .^2) ./ (pi*(1:N));
b(N:-1:1)=-b(N+2:2*N+1);
b=spmask(b,5);
return
