function [y,Ni]=splint(x,N,ratio)
% [y,Ni]=splint(x,N,ratio)
% Linearly interpolates between samples in x(1:N).
% ratio  = output/input T2/T1 ratio > 0.
% Inputs: x, N, and ratio.
% Outputs:  
%  y(1:Ni) = interpolated sequence; Ni =~ N/ratio.

if(ratio>=1)
 y(1)=x(1);
 Ni=fix((N-1)/ratio)+1;
 for k=1:N-1
  if(1+k*ratio <= N)
   k1=fix(k*ratio);
   y(k+1)=x(k1+1)+(k*ratio-k1)*(x(min(N,k1+2))-x(k1+1));
  else
   y(k+1)=0;
  end
 end
elseif (ratio>0)
 Ni=fix((N-1)/ratio)+1;
 if(Ni>N)
  y=[x zeros(1,Ni-N)];
 end
 for k=Ni-1:-1:1,
  ix=fix(k*ratio);
  y(k+1)=y(ix+1)+(k*ratio-ix)*(y(ix+2)-y(ix+1));
 end
else
 error('SPLINT: ratio <= 0.')
end
return
