function [A,c]=spnorm(x,y,L)
% [A,c]=spnorm(x,y,L)
% Normal eq. setup for least-squares polynomial.
% x,y=data row vectors of same length; L= order of
% polynomial; A,c= arrays in equation (11.4).
% Inputs:
%    x,y    = row vectors with x,y data.
%    L      = order of b0 + b1*x +...+ bL*x**L.
% Outputs:  
%    A      = coeff. matrix in (11.5), (L+1)x(L+1).
%    c      = column vector in (11.7), (L+1)x1.

N=length(x);
if(N ~= length(y)),
   error('SPNORM: Lengths of x and y are not the same.')
end
if (L<=0) | (L>N),
   error('SPNORM: L is <0 or >data length.')
end
A=zeros(L+1); c=zeros(L+1,1);
for j=0:L,
   for i=0:L,
      sA=0;
      for k=1:N,
         sA=sA+x(k)^(i+j);
      end
      A(i+1,j+1)=sA;
      A(j+1,i+1)=sA;
   end
   sc=0;
   for k=1:N,
      sc=sc+y(k)*x(k)^(j);
   end
   c(j+1)=sc;
end
return
