function [t0,t10,t90,t100]=sprftm(idir,x)
% [t0,t10,t90,t100]=sprftm(idir,x)
% Finds rise or fall time parameters in row vector x.
% Uses linear interpolation. (t0,t100)=(bottom,top)
% of rise; (t10,t90)=(10,90)% points. See Section 13.4.
% idir=1 for rise time; -1 for fall time.
% Outputs:  
%    t0     = index of bottom of rise.
%    t10    = index of 10% point on rise.
%    t90    = index of 90% point on rise.
%    t100   = index of top of rise.
% IMPORTANT: t values are tied to the indices of x; that is,
% t=1 for x(1), t=2 for x(2), etc.  These may be translated
% to other values after executing the function.


N=length(x);
if (idir~=-1)&(idir~=+1),
   error('SPRFTM: idir is neither -1 nor +1.');
end
[xmn,imn,xmx,imx]=splmts(x);
if idir==+1,
   t0=1; t100=imx;
else
   t100=imx; t0=N;
   for i=imx+1:N-1,
      if(x(i)==xmx),
       t100=i;
      end
   end
end
for i=(t100-idir):-idir:t0,
   if (x(i)>=x(i+idir))&(x(i)<x(t100))
      t0=i+idir;
      break
   end
end
if x(t0)==x(t100),
   error('SPRFTM: xmin=xmax.');
end
a90=0.9*(x(t100)-x(t0))+x(t0);
for i=t100:-idir:t0,
   if x(i)<a90,
      break
   end
end
t90=i+idir*(a90-x(i))/(x(i+idir)-x(i));
a10=0.1*(x(t100)-x(t0))+x(t0);
for i=t100:-idir:t0,
   if x(i)<a10,
      break
   end
end
t10=i+idir*(a10-x(i))/(x(i+idir)-x(i));
return
