function [y,Ni]=spzint(x,N,ratio)
% [y,Ni]=spzint(x,N,ratio)
% Changes time step in x(1:N) using zero padding.
% ratio = time step ratio T2/T1. Must be >0.
% See Chapter 10, Section 10.3 and Fig. 10.12.
% Outputs: interpolated sequence y(1:Ni); Ni =~ N/ratio.

if(ratio<=0)|(N<3),
 error('SPZINT: ratio<=0 or length(x)<3.');
end
[m,n]=size(x);
if(m~=1),
 error('SPZINT: x data vector should have 1 row.');
end
if(N>n),
 x=[x,zeros(1,N-n)];
end
X=fft(x,N);
Ne=max(N,round(N/ratio));
if Ne>N
 if 2*fix(N/2)==N
  H=X(N/2+1)/2;
  Y=[X(1:N/2) H zeros(1,Ne-N-1) H X(N/2+2:N)];
 else
  Y=[X(1:(N+1)/2) zeros(1,Ne-N) X((N+3)/2:N)];
 end
end
scale=Ne/N;
y=scale*real(ifft(Y,Ne));
[y,Ny]=splint(y,Ne,scale*ratio);
Ni=fix((N-1)/ratio)+1;
return
