% sptest.m
% Latest date: 02/28/95
% 
% **********************************************************************
%                            sptest.m                                  *
%             SIGNAL PROCESSING ALGORITHMS FUNCTION TESTS              *
%                      Source code in Matlab                           *
% **********************************************************************
% 
% This program tests each of the functions in SIGNAL PROCESSING
% ALGORITHMS IN MATLAB, in the SPALIB directory on the disk that comes
% with the text. In each test the message "passed" or "failed" is
% printed after the name of the routine. If a test fails, execution will
% pause so that the failure may be noted. Each test checks for correct
% performance for a specific input, not for all inputs, so the test is a
% check rather than a guarantee that the routine is working correctly.
% In each test a perfomance factor, q, is computed as a function of the
% function output and compared with its correct value to determine
% success or failure of the test. q is then sent to function SPOUT.M,
% which prints the result of the test. (SPOUT.M is included on the disk in
% the SPTEST subdirectory).  If a test fails, check the listings of
% both the m-file and this program against those on the disk. If the
% listings agree, try printing the actual value of q for this test.
% There may be a roundoff error.  If all else fails to yield a reason 
% for the failure, call one of the authors at a reasonable hour.
% 
  clear;
  fprintf('Start testing the functions in SPALIB:\n');
  flag=0;
% 
% **********************************************************************
% 
% TEST OF SPBFCT.
  q=10*spbfct(5,3) + spbfct(3,3);
  flag=spout('spbfct',q,606,flag);
% 
% **********************************************************************
% 
% TEST OF SPBILN.
  d=[0.1056, 0, 0]; c=[0.1056, 0.4595, 1.0];
  [b,a]=spbiln(d,c);
  q=sum(round(1000*b) + round(1000*a));
  flag=spout('spbiln',q,539,flag);
% 
% **********************************************************************
% 
% TEST OF SPBSSL.
  [d,c]=spbssl(3,2);
  q=round(d) + sum(round(c));
  flag=spout('spbssl',q,92,flag);
% 
% **********************************************************************
% 
% TEST OF SPBWCF.
  [d,c]=spbwcf(5,2);
  q=d + sum(round(1000*c));
  flag=spout('spbwcf',q,3619,flag);
% 
% **********************************************************************
% 
% TEST OF SPCBII.
  [d,c]=spcbii(6,2,1.5,10.);
  q=fix(100*sum(d)) + round(100*sum(c));
  flag=spout('spcbii',q,4015,flag);
% 
% **********************************************************************
% 
% TEST OF SPCFLT.
  b=[1,2; 2,1]; a=[2,4,1; 1,2,4]; x=[1:5]; px=[1;2]; py=[2,1];
  [y,px,py]=spcflt(b,a,x,px,py);
  q=round(100*sum(y))+sum(round(100*sum(px)))+sum(round(100*sum(py)));
  flag=spout('spcflt',q,5700,flag);
% 
% **********************************************************************
% 
% TEST OF SPCHBI.
  [d,c]=spchbi(6,2,0.5);
  q=round(1000*sum(d)) + round(1000*sum(c));
  flag=spout('spchbi',q,2462,flag);
% 
% **********************************************************************
% 
% TEST OF SPCHRP
  X=spchrp([1:5],0.2,0.3,3);
  q=round(abs(1000*sum(X)));
  flag=spout('spchrp',q,4344,flag);
% 
% **********************************************************************
% 
% TEST OF SPCOMP.
  X=spcomp([1:5],0.2);
  q=round(abs(1000*X));
  flag=spout('spcomp',q,4253,flag);
% 
% **********************************************************************
% 
% TEST OF SPCONV.
  x=[1,2,3]; y=[4,5,6,7];
  [cxy,M]=spconv(x,y);
  q=100*M + sum(round(cxy));
  flag=spout('spconv',q,732,flag);
% 
% **********************************************************************
% 
% TEST OF SPCORR.
  x=[1,2,3]; y=[4,5,6,7];
  [rxy,M]=spcorr(x,y);
  q=100*M + sum(round(rxy));
  flag=spout('spcorr',q,497,flag);
% 
% **********************************************************************
% 
% TEST OF SPCROS.
  x1=[1:10]; x2=[-5:4]; NDFT=8; iwindo=3; ovrlap=0.75;
  [y,nsgmts]=spcros(x1,x2,NDFT,iwindo,ovrlap);
  q=100*nsgmts + sum(round(100*real(y))+round(100*imag(y)));
  flag=spout('spcros',q,-1958,flag);
%
% **********************************************************************
% 
% TEST OF SPDECI.
  x=[1:8]; N=7; ratio=3;
  [y,Nd]=spdeci(x,N,ratio);
  q=sum(y) + Nd;
  flag=spout('spdeci',q,15,flag);
% 
% **********************************************************************
% 
% TEST OF SPDURB.
  Aavect=[5,3,2,1];
  b=spdurb(Aavect);
  q=sum(round(1000*b));
  flag=spout('spdurb',q,589,flag);
%
% **********************************************************************
% 
% TEST OF SPEXPN.
  x=[1,2,3]; y=[6,12,24];
  [a,b]=spexpn(x,y);
  q=10*round(a) + round(b);
  flag=spout('spexpn',q,32,flag);
% 
% **********************************************************************
% 
% TEST OF SPFBLT.
  d=1; c=[1,sqrt(2),1]; iband=4; f1=0.1; f2=0.2;
  [b,a]=spfblt(d,c,iband,f1,f2);
  q=sum(round(1000*b) + round(1000*a));
  flag=spout('spfblt',q,745,flag);
% 
% **********************************************************************
% 
% TEST OF SPFILT.
  b=[1,2]; a=[1,-1,0.89]; x=[1:4]; px=[-1:1]; py=1;
  [y,px,py]=spfilt(b,a,x,px,py);
  q=sum(round(100*y) + round(100*py)) + 100*sum(px);
  flag=spout('spfilt',q,6684,flag);
% 
% **********************************************************************
% 
% TEST OF SPFIRD.
  L=6; iband=3; fln=0.1; fhn=0.2; iwndo=3;
  b=spfird(L,iband,fln,fhn,iwndo);
  q=sum(round(1000*b));
  flag=spout('spfird',q,316,flag);
% 
% **********************************************************************
% 
% TEST OF SPFIRF.
  b=[-5:1:5]; x=-[3:10];
  y=spfirf(b,x);
  q=sum(round(y));
  flag=spout('spfirf',q,582,flag);
% 
% **********************************************************************
% 
% TEST OF SPFIRL.
  L=6; fcn=0.2; iwndo=6;
  b=spfirl(L,fcn,iwndo);
  q=sum(round(1000*b));
  flag=spout('spfirl',q,806,flag);
% 
% **********************************************************************
% 
% TEST OF SPGAIN.
  b=[-3:3]; a=[1,-1,.89]; freq=.3;
  h=spgain(b,a,freq);
  q=round(real(1000*h)) + round(imag(1000*h));
  flag=spout('spgain',q,3454,flag);
% 
% **********************************************************************
% 
% TEST OF SPHILB.
  L=5;
  b=sphilb(L);
  q=sum(round(1000*b(1:2))) - sum(round(1000*b(3:5)));
  flag=spout('sphilb',q,-688,flag);
% 
% **********************************************************************
% 
% TEST OF SPIIRD.
  Ns=2; f1=.1; f2=.15; f3=.2; f4=.25; dB=10;
  [b,a]=spiird(2,2,Ns,f1,f2,f3,f4,dB);
  [d,c]=spiird(3,3,Ns,f1,f2,f3,f4,dB);
  q=sum(sum(round(1000*b)+round(1000*a)))+...
    sum(sum(round(1000*d)+round(1000*c)));
  flag=spout('spiird',q,2732,flag);
% 
% **********************************************************************
% 
% TEST OF SPLEVS.
  Avect=[3:-1:1]; c=[3,-1,2]';
  b=splevs(Avect,c);
  q=sum(round(1000*b));
  flag=spout('splevs',q,1250,flag);
% 
% **********************************************************************
% 
% TEST OF SPLFIT.
  x=[1:2:7]; y=[2:4:14];
  [a,b]=splfit(x,y);
  q=a+10*b;
  flag=spout('splfit',q,2,flag);
%
%**********************************************************************
%
% TEST OF SPLFLT.
  kappa=[-.91,.93,-.88,.55]; nu=[1.0:0.2:1.8];
  x=[-2:4]; pv=[-9:-3];
  [y,pv]=splflt(kappa,nu,x,pv);
  q=sum(round(100*y)) + sum(round(100*pv));
  flag=spout('splflt',q,-7778,flag);
% 
% **********************************************************************
% 
% TEST OF SPLINT.
  x=[1:5]; N=4; ratio=0.25;
  [y,Ni]=splint(x,N,ratio);
  q=Ni + sum(round(100*y));
  flag=spout('splint',q,3263,flag);
% 
% **********************************************************************
% 
% TEST OF SPLMTS.
  x=[-2:3];
  [x1,i1,x2,i2]=splmts(x);
  q=10*(x1+x2) + (i1+i2);
  flag=spout('splmts',q,17,flag);
% 
% **********************************************************************
% 
% TEST OF SPLSMT.
  N=5; L=3;
  P=splsmt(N,L);
  q=sum(sum(round(10*P)));
  flag=spout('splsmt',q,12,flag);
% 
% **********************************************************************
% 
% TEST OF SPLTCF
  b=[1:3]; a=[1,-1,.89];
  [kappa,nu]=spltcf(b,a);
  q=sum(round(100*kappa)) + sum(round(100*nu));
  flag=spout('spltcf',q,934,flag);
% 
% **********************************************************************
% 
% TEST OF SPMASK.
  x=[1:4]; itype=3;
  [y,tsv]=spmask(x,itype);
  q=sum(round(1000*y)) + round(1000*tsv);
  flag=spout('spmask',q,4222,flag);
% 
% **********************************************************************
% 
% TEST OF SPNLMS.
  x=[-2:3]; d=[1:6]; b=[-1:1]; mu=0.5; sigma=1; alpha=0.8; px=1;
  [y,b,px]=spnlms(x,d,b,mu,sigma,alpha,px);
  q=sum(round(100*y)) + sum(round(100*b)) + sum(px);
  flag=spout('spnlms',q,-2110,flag);
% 
% **********************************************************************
% 
% TEST OF SPNORM.
  x=[1:2:7]; y=[2:4:14]; L=2;
  [A,c]=spnorm(x,y,L);
  q=sum(sum(A)) + sum(c);
  flag=spout('spnorm',q,5580,flag);
% 
% **********************************************************************
% 
% TEST OF SPORTH.
  y=[1:4]; L=2;
  [orth,P]=sporth(y,L);
  q=sum(round(100*y)) + sum(sum(round(100*P)));
  flag=spout('sporth',q,1133,flag);
% 
% **********************************************************************
% 
% TEST OF SPPFLT.
  b=[1,2; 2,1]; a=[2,4,1; 1,2,4]; x=[1:5]; px=[1;2]; py=[2,1];
  [y,px,py]=sppflt(b,a,x,px,py);
  q=round(100*sum(y))+sum(round(100*sum(px)))+sum(round(100*sum(py)));
  flag=spout('sppflt',q,-776,flag);
% 
% **********************************************************************
% 
% TEST OF SPPOLY.
  dx=0.5; y=[1,3,2,5]; L=2;
  b=sppoly(dx,y,L);
  q=sum(round(1000*b));
  flag=spout('sppoly',q,3050,flag);
% 
% **********************************************************************
% 
% TEST OF SPPOWR.
  x=[1:4,1:6]; NDFT=8; iwindo=4; ovrlap=0.75;
  [pds,nsgmts]=sppowr(x,NDFT,iwindo,ovrlap);
  q=100*nsgmts + sum(round(100*pds));
  flag=spout('sppowr',q,4898,flag);

% 
% **********************************************************************
% 
% TEST OF SPPWRC.
  x=[1,2,4]; y=[3,12,48];
  [a,b]=sppwrc(x,y);
  q=round(10*a + b);
  flag=spout('sppwrc',q,32,flag);
% 
% **********************************************************************
% 
% TEST OF SPRESP.
  x=[1:10]; Ny=5; b=[1:3]; a=[1,-1,.89];
  y=spresp(x,Ny,b,a);
  q=sum(round(100*y));
  flag=spout('spresp',q,8087,flag);
% 
% **********************************************************************
% 
% TEST OF SPRFTM.
  x=[-1:-1:-5,-4:5,4:-1:-5,-4:0];
  [r0,r10,r90,r100]=sprftm(1,x);
  [f0,f10,f90,f100]=sprftm(-1,x);
  q=r0+r10-r90+r100 + 10*(f0-f10+f90+f100);
  flag=spout('sprftm',q,332,flag);
% 
% **********************************************************************
% 
% TEST OF SPSTRL.
  L=5;
  S=spstrl(L);
  q=sum(sum(S(:,2:4)));
  flag=spout('spstrl',q,9,flag);
% 
% **********************************************************************
% 
% TEST OF SPUNWR.
  x=[174:2:180,-178:3:-172];
  ux=spunwr(x,2);
  q=ux(7);
  flag=spout('spunwr',q,188,flag);
% 
% **********************************************************************
% 
% TEST OF SPVARI.
  x=[1:9];
  var=spvari(x);
  q=round(10*var);
  flag=spout('spvari',q,75,flag);
% 
% **********************************************************************
% 
% TEST OF SPWLSH.
  logN=3; nseq=5; k=[0:7];
  y=spwlsh(logN,nseq,k);
  q=sum(2.^[0:7] .* y);
  flag=spout('spwlsh',q,-45,flag);
% 
% **********************************************************************
% 
% TEST OF SPWNDO.
  itype=6; N=20; k=[1:20];
  w=spwndo(itype,N,k);
  q=sum(round(100*w));
  flag=spout('spwndo',q,798,flag);
% 
% **********************************************************************
% 
% TEST OF SPXEXP.
  x=[1,2,4,5]; y=x.^3;
  [a,b]=spxexp(x,y);
  q=round(100*a) + round(100*b);
  flag=spout('spxexp',q,138,flag);
% 
% **********************************************************************
% 
% TEST OF SPZINT.
  x=[1,2,3,4,3,2,1]; N=7; ratio=0.4;
  [y,Ni]=spzint(x,N,ratio);
  q=Ni + sum(round(100*y));
  flag=spout('spzint',q,3976,flag);
%
% **********************************************************************
  if(flag==0),
    fprintf('All tests completed successfully.\n');
  else
    fprintf('All tests completed, but not 100%% successfully.\n');
  end
